Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1474)

Unified Diff: chrome/browser/sync/glue/theme_change_processor.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/theme_change_processor.h
diff --git a/chrome/browser/sync/glue/theme_change_processor.h b/chrome/browser/sync/glue/theme_change_processor.h
index 33024d4d6ac0f435275424f90c7abbf238620ba8..28b08ff7e801aea80dee7d086b27c7013890aa7f 100644
--- a/chrome/browser/sync/glue/theme_change_processor.h
+++ b/chrome/browser/sync/glue/theme_change_processor.h
@@ -21,7 +21,7 @@ namespace browser_sync {
class DataTypeErrorHandler;
// This class is responsible for taking changes from the
// ThemeService and applying them to the csync 'syncable'
// model, and vice versa. All operations and use of this class are
// from the UI thread.
class ThemeChangeProcessor : public ChangeProcessor,
@@ -31,16 +31,16 @@ class ThemeChangeProcessor : public ChangeProcessor,
virtual ~ThemeChangeProcessor();
// content::NotificationObserver implementation.
// ThemeService -> csync model change application.
virtual void Observe(int type,
const content::NotificationSource& source,
const content::NotificationDetails& details) OVERRIDE;
// ChangeProcessor implementation.
// csync model -> ThemeService change application.
virtual void ApplyChangesFromSyncModel(
- const csync::BaseTransaction* trans,
- const csync::ImmutableChangeRecordList& changes) OVERRIDE;
+ const syncer::BaseTransaction* trans,
+ const syncer::ImmutableChangeRecordList& changes) OVERRIDE;
protected:
// ChangeProcessor implementation.
@@ -21,7 +21,7 @@ namespace browser_sync {
class DataTypeErrorHandler;
// This class is responsible for taking changes from the
-// ThemeService and applying them to the csync 'syncable'
+// ThemeService and applying them to the syncer 'syncable'
// model, and vice versa. All operations and use of this class are
// from the UI thread.
@@ -31,16 +31,16 @@ class ThemeChangeProcessor : public ChangeProcessor,
virtual ~ThemeChangeProcessor();
// content::NotificationObserver implementation.
- // ThemeService -> csync model change application.
+ // ThemeService -> syncer model change application.
virtual void Observe(int type,
const content::NotificationSource& source,
@@ -31,16 +31,16 @@ class ThemeChangeProcessor : public ChangeProcessor,
const content::NotificationDetails& details) OVERRIDE;
// ChangeProcessor implementation.
- // csync model -> ThemeService change application.
+ // syncer model -> ThemeService change application.
virtual void ApplyChangesFromSyncModel(

Powered by Google App Engine
This is Rietveld 408576698